@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -155,7 +155,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -166,7 +166,21 @@ version 0.0200
     output => 'output-MIDI-device',
   );
 
-  # add stuff to the $rtc->loop
+  sub filter_notes {
+    my ($note) = @_;
+    return $note, $note + 7, $note + 12;
+  }
+  sub filter_tone {
+    my ($event) = @_;
+    my ($ev, $channel, $note, $vel) = $event->@*;
+    my @notes = filter_notes($note);
+    $rtc->send_it([ $ev, $channel, $_, $vel ]) for @notes;
+    return 0;
+  }
+
+  $rtc->add_filter($_ => \&pedal_tone) for qw(note_on note_off);
+
+  # add other stuff to the $rtc->loop...
 
   $rtc->run;
 
